aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorThiago Farina <tfransosi@gmail.com>2010-07-10 01:46:27 -0300
committerLinus Torvalds <torvalds@linux-foundation.org>2010-07-10 10:26:32 -0700
commitbbf253858a878ad4ce137ea6dfe2b6979ef797c7 (patch)
treeccea7f7572db66e33671f1ded175846b2132ddd7
parent724c4efc5fbc1c49361a75a86139e27b2e96c506 (diff)
downloaduemacs-bbf253858a878ad4ce137ea6dfe2b6979ef797c7.tar.gz
uemacs: convert typedef struct REGION to struct region.
Signed-off-by: Thiago Farina <tfransosi@gmail.com> Signed-off-by: Linus Torvalds <torvalds@linux-foundation.org>
-rw-r--r--efunc.h2
-rw-r--r--estruct.h4
-rw-r--r--region.c14
-rw-r--r--word.c2
4 files changed, 11 insertions, 11 deletions
diff --git a/efunc.h b/efunc.h
index dbccde8..44c54e9 100644
--- a/efunc.h
+++ b/efunc.h
@@ -161,7 +161,7 @@ extern int killregion(int f, int n);
extern int copyregion(int f, int n);
extern int lowerregion(int f, int n);
extern int upperregion(int f, int n);
-extern int getregion(REGION *rp);
+extern int getregion(struct region *rp);
/* posix.c */
extern void ttopen(void);
diff --git a/estruct.h b/estruct.h
index dfffe0b..616c4c6 100644
--- a/estruct.h
+++ b/estruct.h
@@ -509,11 +509,11 @@ struct buffer {
* The starting position of a region, and the size of the region in
* characters, is kept in a region structure. Used by the region commands.
*/
-typedef struct {
+struct region {
struct line *r_linep; /* Origin struct line address. */
short r_offset; /* Origin struct line offset. */
long r_size; /* Length in characters. */
-} REGION;
+};
/*
* All text is kept in circularly linked lists of "struct line" structures. These
diff --git a/word.c b/word.c
index 4bd8739..119e4ac 100644
--- a/word.c
+++ b/word.c
@@ -651,7 +651,7 @@ int wordcount(int f, int n)
int nlines; /* total number of lines in region */
int avgch; /* average number of chars/word */
int status; /* status return code */
- REGION region; /* region to look at */
+ struct region region; /* region to look at */
/* make sure we have a region to count */
if ((status = getregion(&region)) != TRUE)
diff --git a/region.c b/region.c
index 9a97cd4..22193ae 100644
--- a/region.c
+++ b/region.c
@@ -1,4 +1,4 @@
-/* REGION.C
+/* region.c
*
* The routines in this file
* deal with the region, that magic space
@@ -23,7 +23,7 @@
int killregion(int f, int n)
{
int s;
- REGION region;
+ struct region region;
if (curbp->b_mode & MDVIEW) /* don't allow this command if */
return (rdonly()); /* we are in read only mode */
@@ -48,7 +48,7 @@ int copyregion(int f, int n)
struct line *linep;
int loffs;
int s;
- REGION region;
+ struct region region;
if ((s = getregion(&region)) != TRUE)
return (s);
@@ -87,7 +87,7 @@ int lowerregion(int f, int n)
int loffs;
int c;
int s;
- REGION region;
+ struct region region;
if (curbp->b_mode & MDVIEW) /* don't allow this command if */
return (rdonly()); /* we are in read only mode */
@@ -124,7 +124,7 @@ int upperregion(int f, int n)
int loffs;
int c;
int s;
- REGION region;
+ struct region region;
if (curbp->b_mode & MDVIEW) /* don't allow this command if */
return (rdonly()); /* we are in read only mode */
@@ -150,7 +150,7 @@ int upperregion(int f, int n)
/*
* This routine figures out the
* bounds of the region in the current window, and
* fills in the fields of the "REGION" structure pointed
* to by "rp". Because the dot and mark are usually very
* close together, we scan outward from dot looking for
* mark. This should save time. Return a standard code.
@@ -158,7 +158,7 @@ int upperregion(int f, int n)
* an "ABORT" status; we might make this have the
* conform thing later.
*/
-int getregion(REGION *rp)
+int getregion(struct region *rp)
{
struct line *flp;
struct line *blp;
@@ -150,7 +150,7 @@ int upperregion(int f, int n)
* This routine figures out the
* bounds of the region in the current window, and
- * fills in the fields of the "REGION" structure pointed
+ * fills in the fields of the "struct region" structure pointed
* to by "rp". Because the dot and mark are usually very
* close together, we scan outward from dot looking for